{"%",13,-124,0,0},
{"%CHANGE",13,-124,0,0},
{"%TOTAL",13,-124,0,0},
{".",13,9,0,0},
{"ABS",13,-124,0,0},
{"ACOS",13,-124,0,0},
{"ACOSH",13,-124,0,0},
{"ACOT",13,-124,0,0},
{"ACSC",13,-124,0,0},
{"ADDCOL",13,-124,0,0| 1},
{"ADDROW",13,-124,0,0| 1},
{"ALOG",13,-124,0,0},
{"ARC",13,-124,0,0},
{"ARG",13,-124,0,0},
{"ASEC",13,-124,0,0},
{"ASIN",13,-124,0,0},
{"ASINH",13,-124,0,0},
{"ATAN",13,-124,0,0},
{"ATANH",13,-124,0,0},
{"Airy_Ai",13,9,0,0},
{"Airy_Bi",13,9,0,0},
{"Ans",13,4,0,0},
{"Archive",13,77,0,0| 1},
{"BINOMIAL",13,9,0,0},
{"BesselI",13,9,0,0},
{"BesselJ",13,9,0,0},
{"BesselK",13,9,0,0},
{"BesselY",13,9,0,0},
{"Beta",13,9,0,0},
{"Bezier",13,9,0,0},
{"BlockDiagonal",13,9,0,0},
{"CEILING",13,-124,0,0},
{"CHOOSE",13,-124,0,0| 1},
{"COLNORM",13,-124,0,0},
{"COMB",13,-124,0,0},
{"CONCAT",13,-124,0,0},
{"COND",13,-124,0,0},
{"CONJ",13,-124,0,0},
{"COS",13,-124,0,0},
{"COSH",13,-124,0,0},
{"COT",13,-124,0,0},
{"CROSS",13,-124,0,0},
{"CSC",13,-124,0,0},
{"Celsius2Fahrenheit",13,9,0,0},
{"Ci",13,9,0,0},
{"Ci0",13,9,0,0},
{"Circle",13,77,0,0},
{"ClrDraw",13,8,0,0},
{"ClrGraph",13,8,0,0},
{"ClrIO",13,8,0,0},
{"CopyVar",13,77,0,0| 1},
{"CyclePic",13,77,0,0},
{"DEGXRAD",13,-124,0,0},
{"DELCOL",13,-124,0,0| 1},
{"DELROW",13,-124,0,0| 1},
{"DET",13,-124,0,0},
{"DISP",13,-124,0,0| 1},
{"DOT",13,-124,0,0},
{"DROP",13,85,0,0},
{"DUP",13,85,0,0},
{"DelFold",13,77,0,0| 1},
{"DelVar",13,77,0,0| 1},
{"Det",13,9,0,0},
{"Dirac",13,9,0,0},
{"DispG",13,8,0,0},
{"DispHome",13,8,0,0},
{"DrawFunc",13,77,0,0},
{"DrawInv",13,77,0,0},
{"DrawParm",13,77,0,0},
{"DrawPol",13,77,0,0},
{"DrawSlp",13,77,0,0},
{"DrwCtour",13,77,0,0},
{"EDITMAT",13,-124,0,0| 1},
{"EIGENVAL",13,-124,0,0},
{"EIGENVV",13,-124,0,0},
{"EXP",13,-124,0,0},
{"EXPM1",13,-124,0,0},
{"EXPORT",13,77,0,0| 1},
{"Ei",13,9,0,0},
{"Ei0",13,9,0,0},
{"Ei_f",13,9,0,0},
{"Eta",13,9,0,0},
{"Exec",13,77,0,0},
{"FLOOR",13,-124,0,0},
{"FNROOT",13,-124,0,0| 1},
{"Factor",13,9,0,0},
{"Fahrenheit2Celsius",13,-124,0,0},
{"Fill",13,77,0,0| 1},
{"GETKEY",13,-124,0,0},
#ifndef NO_RTTI
{"GF",13,9,0,0},
#endif
{"Gamma",13,9,0,0},
{"Gcd",13,9,0,0},
{"Gcdex",13,9,0,0},
{"Get",13,77,0,0| 1},
{"GetCalc",13,77,0,0| 1},
{"GetFold",13,8,0,0},
{"Graph",13,77,0,0},
{"HMSX",13,-124,0,0},
{"Heaviside",13,9,0,0},
{"IDENMAT",13,-124,0,0},
{"IFTE",13,85,0,0},
{"IM",13,-124,0,0},
{"INPUT",13,-124,0,0| 1},
{"INVERSE",13,-124,0,0},
{"ISOLATE",13,-124,0,0| 1},
{"ITERATE",13,-124,0,0| 1},
{"Input",13,77,0,0| 1},
{"InputStr",13,77,0,0| 1},
{"Int",13,9,0,0},
{"Inverse",13,9,0,0},
{"JordanBlock",13,9,0,0},
{"Kronecker",13,9,0,0},
{"LINE",13,-124,0,0},
{"LINEAR?",13,-124,0,0},
{"LN",13,-124,0,0},
{"LNP1",13,-124,0,0},
{"LOG",13,-124,0,0},
{"LQ",13,-124,0,0},
{"LSQ",13,-124,0,0},
{"LU",13,9,0,0| 1},
{"Line",13,77,0,0},
{"LineHorz",13,77,0,0},
{"LineTan",13,77,0,0},
{"LineVert",13,77,0,0},
{"MAKELIST",13,-124,0,0| 1},
{"MAKEMAT",13,-124,0,0| 1},
{"MANT",13,-124,0,0},
{"MAX",13,-124,0,0},
{"MAXREAL",13,2,0,0},
{"MIN",13,-124,0,0},
{"MINREAL",13,2,0,0},
{"MINUS",13,-124,0,0},
{"MOD",13,21,0,0},
{"MSGBOX",13,-124,0,0},
{"NOP",13,85,0,0},
{"NORMALD",13,9,0,0},
{"NTHROOT",13,23,0,0},
{"NewFold",13,77,0,0| 1},
{"NewPic",13,77,0,0},
{"Nop",13,9,0,0},
{"Nullspace",13,9,0,0},
{"OVER",13,85,0,0},
{"Output",13,77,0,0},
{"Ox_2d_unit_vector",13,9,0,0},
{"Ox_3d_unit_vector",13,9,0,0},
{"Oy_2d_unit_vector",13,9,0,0},
{"Oy_3d_unit_vector",13,9,0,0},
{"Oz_3d_unit_vector",13,9,0,0},
{"PERM",13,-124,0,0},
{"PICK",13,85,0,0},
{"PIECEWISE",13,9,0,0| 1},
{"PIXOFF",13,-124,0,0},
{"PIXON",13,-124,0,0},
{"POISSON",13,9,0,0},
{"POLYCOEF",13,9,0,0| 1},
{"POLYEVAL",13,-124,0,0},
{"POLYFORM",13,-124,0,0| 1},
{"POLYROOT",13,-124,0,0| 1},
{"POS",13,-124,0,0},
{"PRINT",13,-124,0,0| 1},
{"Pause",13,77,0,0},
{"Phi",13,9,0,0},
{"Pictsize",13,9,0,0},
{"PopUp",13,77,0,0| 1},
{"Prompt",13,77,0,0| 1},
{"Psi",13,9,0,0},
{"Psi_minus_ln",13,9,0,0},
{"PtOff",13,77,0,0},
{"PtOn",13,77,0,0},
{"PtText",13,77,0,0},
{"PxlOff",13,77,0,0},
{"PxlOn",13,77,0,0},
{"QR",13,9,0,0| 1},
{"QUAD",13,-124,0,0| 1},
{"QUOTE",13,-124,0,0| 1},
{"Quo",13,9,0,0},
{"RADXDEG",13,-124,0,0},
{"RANDMAT",13,-124,0,0| 1},
{"RANDOM",13,77,0,0},
{"RANDSEED",13,77,0,0},
{"RANK",13,-124,0,0},
{"RCL",13,85,0,0},
{"RE",13,-124,0,0},
{"RECT",13,-124,0,0},
{"RECURSE",13,-124,0,0| 1},
{"REDIM",13,-124,0,0| 1},
{"REPLACE",13,-124,0,0| 1},
{"REVERSE",13,-124,0,0},
{"ROUND",13,-124,0,0},
{"ROWNORM",13,-124,0,0},
{"RREF",13,-124,0,0},
{"RandSeed",13,77,0,0},
{"Rank",13,9,0,0},
{"RclPic",13,77,0,0| 1},
{"Rem",13,9,0,0},
{"Resultant",13,9,0,0},
{"RplcPic",13,77,0,0| 1},
{"Rref",13,9,0,0},
{"SCALE",13,-124,0,0| 1},
{"SCALEADD",13,-124,0,0| 1},
{"SCHUR",13,-124,0,0},
{"SEC",13,-124,0,0},
{"SIGN",13,-124,0,0},
{"SIN",13,-124,0,0},
{"SINH",13,-124,0,0},
{"SIZE",13,-124,0,0},
{"SORT",13,-124,0,0},
{"SPECNORM",13,-124,0,0},
{"SPECRAD",13,-124,0,0},
{"SUB",13,-124,0,0| 1},
{"SVD",13,-124,0,0},
{"SVL",13,-124,0,0},
{"SWAP",13,85,0,0},
{"SWAPCOL",13,-124,0,0| 1},
{"SWAPROW",13,-124,0,0| 1},
{"SetFold",13,77,0,0| 1},
{"Si",13,9,0,0},
{"SiCi_f",13,9,0,0},
{"SiCi_g",13,9,0,0},
{"SortA",13,77,0,0| 1},
{"SortD",13,77,0,0| 1},
{"StoPic",13,77,0,0| 1},
{"Store",13,9,0,0| 1},
{"Sum",13,9,0,0| 1},
{"TAN",13,-124,0,0},
{"TANH",13,-124,0,0},
{"TAYLOR",13,-124,0,0| 1},
{"TRACE",13,-124,0,0},
{"TRN",13,-124,0,0},
{"TRUNCATE",13,-124,0,0},
{"TeX",13,9,0,0},
{"UTPC",13,9,0,0},
{"UTPF",13,9,0,0},
{"UTPN",13,9,0,0},
{"UTPT",13,9,0,0},
{"Unarchiv",13,77,0,0| 1},
{"VAS",13,9,0,0},
{"VAS_positive",13,9,0,0},
{"VIEWS",13,77,0,0| 1},
{"WAIT",13,-124,0,0},
{"XHMS",13,-124,0,0},
{"XPON",13,-124,0,0},
{"Zeta",13,9,0,0},
{"ZoomRcl",13,77,0,0},
{"ZoomSto",13,77,0,0},
{"a2q",13,9,0,0},
{"abcuv",13,9,0,0},
{"about",13,9,0,0},
{"abs",13,9,0,0},
{"abscissa",13,9,0,0},
{"accumulate_head_tail",13,9,0,0},
{"acos",13,9,0,0},
{"acos2asin",13,9,0,0},
{"acos2atan",13,9,0,0},
{"acosh",13,9,0,0},
{"acot",13,9,0,0},
{"acoth",13,9,0,0},
{"acsc",13,9,0,0},
{"add",13,9,0,0| 1},
{"add_autosimplify",13,9,0,0},
{"add_language",13,9,0,0},
{"additionally",13,9,0,0| 1},
{"adjoint_matrix",13,9,0,0},
{"affichage",13,9,0,0},
{"affix",13,9,0,0},
{"alg",13,9,0,0},
{"algsubs",13,9,0,0},
{"algvar",13,9,0,0},
{"alog10",13,9,0,0},
{"alors",13,49,0,0| 1},
{"altitude",13,9,0,0},
{"and",13,33,0,0| 1},
{"angle",13,9,0,0},
{"angleat",13,9,0,0| 1},
{"angleatraw",13,9,0,0},
{"animate",13,9,0,0},
{"animate3d",13,9,0,0},
{"animation",13,9,0,0},
{"ans",13,9,0,0},
{"append",13,9,0,0},
{"apply",13,9,0,0},
{"approx",13,9,0,0},
{"arc",13,9,0,0| 1},
{"arcLen",13,9,0,0},
{"archive",13,9,0,0},
{"arclen",13,9,0,0},
{"area",13,9,0,0},
{"areaat",13,9,0,0| 1},
{"areaatraw",13,9,0,0},
{"areaplot",13,9,0,0},
{"arg",13,9,0,0},
{"array",13,9,0,0},
{"array_sto",13,9,0,0| 1},
{"as_function_of",13,9,0,0| 1},
{"asc",13,9,0,0},
{"asec",13,9,0,0},
{"asin",13,9,0,0},
{"asin2acos",13,9,0,0},
{"asin2atan",13,9,0,0},
{"asinh",13,9,0,0},
{"assert",13,77,0,0},
{"assign",13,9,0,0},
{"assume",13,9,0,0| 1},
{"atan",13,9,0,0},
{"atan2",13,9,0,0},
{"atan2acos",13,9,0,0},
{"atan2asin",13,9,0,0},
{"atanh",13,9,0,0},
{"atrig2ln",13,9,0,0},
{"augment",13,9,0,0},
{"autosimplify",13,9,0,0},
{"avance",13,126,0,0},
{"avgRC",13,9,0,0},
{"axis",13,9,0,0},
{"back",13,9,0,0},
{"background",13,9,0,0| 1},
{"backward",13,9,0,0},
{"baisse_crayon",13,126,0,0},
{"bar_plot",13,9,0,0},
{"barplot",13,9,0,0},
{"barycenter",13,9,0,0},
{"basis",13,9,0,0},
{"batons",13,9,0,0},
{"bernoulli",13,9,0,0},
{"besselI",13,9,0,0},
{"besselJ",13,9,0,0},
{"besselK",13,9,0,0},
{"besselY",13,9,0,0},
{"betad",13,9,0,0},
{"betad_cdf",13,9,0,0},
{"betad_icdf",13,9,0,0},
{"bezier",13,9,0,0},
{"bezout_entiers",13,9,0,0},
{"binomial",13,9,0,0},
{"binomial_cdf",13,9,0,0},
{"binomial_icdf",13,9,0,0},
{"binprint",13,9,0,0},
{"bisector",13,9,0,0},
{"bitand",13,9,0,0},
{"bitmap",13,9,0,0},
{"bitor",13,9,0,0},
{"bitxor",13,9,0,0},
{"black",13,2,0,0},
{"blockmatrix",13,9,0,0},
{"blockmatrix_mult_size",13,9,0,0},
{"blue",13,2,0,0},
{"border",13,9,0,0},
{"bounded_function",13,9,0,0},
{"boxwhisker",13,9,0,0},
{"break",13,68,0,0},
{"breakpoint",13,9,0,0| 1},
{"c1oc2",13,9,0,0},
{"c1op2",13,9,0,0},
{"cFactor",13,9,0,0},
{"cSolve",13,9,0,0| 1},
{"cZeros",13,9,0,0| 1},
{"cache_tortue",13,126,0,0},
{"calc_mode",13,9,0,0},
{"camembert",13,9,0,0},
{"canonical_form",13,9,0,0},
{"cap",13,126,0,0},
{"cas_setup",13,9,0,0},
{"caseval",13,9,0,0},
{"cat",13,9,0,0},
{"cauchy",13,9,0,0},
{"cauchy_cdf",13,9,0,0},
{"cauchy_icdf",13,9,0,0},
{"cauchyd",13,9,0,0},
{"cauchyd_cdf",13,9,0,0},
{"cauchyd_icdf",13,9,0,0},
{"cd",13,9,0,0},
{"cdf",13,9,0,0},
{"cdfplot",13,9,0,0},
{"ceil",13,9,0,0},
{"ceiling",13,9,0,0},
{"cell",13,9,0,0},
{"center",13,9,0,0},
{"center2interval",13,9,0,0},
{"centered_cube",13,9,0,0},
{"centered_tetrahedron",13,9,0,0},
{"centre",13,9,0,0},
{"cercle",13,9,0,0| 1},
{"cfactor",13,9,0,0},
{"cfsolve",13,9,0,0},
{"changebase",13,9,0,0},
{"char",13,9,0,0},
{"charpoly",13,9,0,0},
{"chinrem",13,9,0,0},
{"chisquare",13,9,0,0},
{"chisquare_cdf",13,9,0,0},
{"chisquare_icdf",13,9,0,0},
{"chisquared",13,9,0,0},
{"chisquared_cdf",13,9,0,0},
{"chisquared_icdf",13,9,0,0},
{"chisquaret",13,9,0,0},
{"choice",13,9,0,0},
{"cholesky",13,9,0,0},
{"choosebox",13,9,0,0| 1},
{"chr",13,9,0,0},
{"chrem",13,9,0,0},
{"circle",13,9,0,0| 1},
{"circumcircle",13,9,0,0},
{"classes",13,9,0,0},
{"clear",13,9,0,0},
{"clearscreen",13,126,0,0},
{"click",13,9,0,0| 1},
{"close",13,9,0,0| 1},
{"coeff",13,9,0,0},
{"coeffs",13,9,0,0},
{"col",13,9,0,0},
{"colDim",13,9,0,0},
{"colNorm",13,9,0,0},
{"colSwap",13,9,0,0},
{"coldim",13,9,0,0},
{"collect",13,9,0,0},
{"colnorm",13,9,0,0},
{"color",13,9,0,0},
{"colspace",13,9,0,0},
{"colswap",13,9,0,0},
{"comDenom",13,9,0,0},
{"comb",13,9,0,0},
{"combine",13,9,0,0},
{"comment",13,9,0,0},
{"common_perpendicular",13,9,0,0},
{"companion",13,9,0,0},
{"compare",13,9,0,0},
{"complex",13,9,0,0},
{"complexroot",13,9,0,0},
{"concat",13,9,0,0},
{"cond",13,9,0,0},
{"cone",13,9,0,0},
{"confidence",13,9,0,0},
{"conic",13,9,0,0},
{"conj",13,9,0,0},
{"conjugate_gradient",13,9,0,0},
{"cont",13,9,0,0| 1},
{"contains",13,9,0,0},
{"content",13,9,0,0},
{"contourplot",13,9,0,0| 1},
{"convert",13,9,0,0},
{"convert3d",13,9,0,0},
{"convertir",13,9,0,0},
{"convexhull",13,9,0,0},
{"coordinates",13,9,0,0},
{"coordonnees",13,9,0,0},
{"copy",13,9,0,0},
{"correlation",13,9,0,0},
{"cos",13,9,0,0},
{"cos2sintan",13,9,0,0},
{"cosh",13,9,0,0},
{"cot",13,9,0,0},
{"cote",13,9,0,0},
{"coth",13,9,0,0},
{"count",13,9,0,0},
{"count_eq",13,9,0,0},
{"count_inf",13,9,0,0},
{"count_sup",13,9,0,0},
{"courbe_parametrique",13,9,0,0| 1},
{"courbe_polaire",13,9,0,0| 1},
{"covariance",13,9,0,0},
{"covariance_correlation",13,9,0,0},
{"cp",13,9,0,0},
{"cpartfrac",13,9,0,0},
{"crationalroot",13,9,0,0},
{"crayon",13,126,0,0},
{"critical",13,9,0,0},
{"cross",13,9,0,0},
{"crossP",13,9,0,0},
{"cross_ratio",13,9,0,0},
{"crossproduct",13,9,0,0},
{"csc",13,9,0,0},
{"csch",13,9,0,0},
{"csolve",13,9,0,0| 1},
{"csv2gen",13,9,0,0},
{"cube",13,9,0,0},
{"cumSum",13,9,0,0},
{"cumsum",13,9,0,0},
{"cumulated_frequencies",13,9,0,0},
{"curl",13,9,0,0| 1},
{"current_sheet",13,9,0,0| 1},
{"curvature",13,9,0,0},
{"curve",13,9,0,0},
{"cyan",13,2,0,0},
{"cycle2perm",13,9,0,0},
{"cycleinv",13,9,0,0},
{"cycles2permu",13,9,0,0},
{"cyclotomic",13,9,0,0},
{"cylinder",13,9,0,0},
{"czeros",13,9,0,0},
{"dayofweek",13,9,0,0},
{"de",13,57,0,0| 1},
{"deSolve",13,77,0,0| 1},
{"debug",13,9,0,0| 1},
{"debug_infolevel",13,5,0,0},
{"debut_enregistrement",13,126,0,0},
{"decrement",13,9,0,0| 1},
{"degree",13,9,0,0},
{"del",13,77,0,0},
{"delcols",13,9,0,0},
{"delrows",13,9,0,0},
{"deltalist",13,9,0,0},
{"denom",13,9,0,0},
{"densityplot",13,9,0,0| 1},
{"deriver",13,9,0,0},
{"desolve",13,9,0,0| 1},
{"dessine_tortue",13,126,0,0},
{"det",13,9,0,0},
{"det_minor",13,9,0,0},
{"developper",13,9,0,0},
{"developper_transcendant",13,9,0,0},
{"dfc",13,9,0,0},
{"dfc2f",13,9,0,0},
{"diag",13,9,0,0},
{"diff",13,9,0,0| 1},
{"dim",13,9,0,0},
{"dir",13,9,0,0},
{"display",13,9,0,0},
{"disque",13,126,0,0},
{"disque_centre",13,126,0,0},
{"distance",13,9,0,0},
{"distance2",13,9,0,0},
{"distanceat",13,9,0,0| 1},
{"distanceatraw",13,9,0,0},
{"div",13,22,0,0},
{"divcrement",13,9,0,0| 1},
{"divergence",13,9,0,0| 1},
{"divide",13,9,0,0},
{"divis",13,9,0,0},
{"division_point",13,9,0,0},
{"divisors",13,9,0,0},
{"divmod",13,9,0,0},
{"divpc",13,9,0,0},
{"dodecahedron",13,9,0,0},
{"domain",13,9,0,0},
{"dot",13,9,0,0},
{"dotP",13,9,0,0},
{"dotprod",13,9,0,0},
{"down",13,126,0,0},
{"draw_arc",13,9,0,0},
{"draw_circle",13,9,0,0},
{"draw_filled_arc",13,9,0,0},
{"draw_filled_circle",13,9,0,0},
{"draw_line",13,9,0,0},
{"draw_pixel",13,9,0,0},
{"draw_polygon",13,9,0,0},
{"draw_rectangle",13,9,0,0},
{"draw_string",13,9,0,0},
{"droit",13,9,0,0},
{"droite",13,9,0,0| 1},
{"droite_tangente",13,9,0,0},
{"dsolve",13,9,0,0| 1},
{"dtype",13,9,0,0},
{"e2r",13,9,0,0},
{"ecart_type",13,9,0,0},
{"ecart_type_population",13,9,0,0},
{"ecris",13,126,0,0},
{"efface",13,126,0,0},
{"egcd",13,9,0,0},
{"egv",13,9,0,0},
{"egvl",13,9,0,0},
{"eigVc",13,9,0,0},
{"eigVl",13,9,0,0},
{"eigenvals",13,9,0,0},
{"eigenvalues",13,9,0,0},
{"eigenvectors",13,9,0,0},
{"eigenvects",13,9,0,0},
{"element",13,9,0,0},
{"eliminate",13,9,0,0},
{"ellipse",13,9,0,0},
{"entry",13,9,0,0},
{"envelope",13,9,0,0},
{"epsilon2zero",13,9,0,0| 1},
{"equal2diff",13,9,0,0},
{"equal2list",13,9,0,0},
{"equation",13,9,0,0},
{"equilateral_triangle",13,9,0,0| 1},
{"erase3d",13,9,0,0},
{"erf",13,9,0,0},
{"erfc",13,9,0,0},
{"erfs",13,9,0,0},
{"et",13,33,0,0| 1},
{"euler",13,9,0,0},
{"euler_mac_laurin",13,9,0,0},
{"eval",13,9,0,0| 1},
{"eval_level",13,9,0,0},
{"evala",13,9,0,0},
{"evalb",13,9,0,0| 1},
{"evalc",13,9,0,0},
{"evalf",13,9,0,0},
{"evalfa",13,9,0,0},
{"evalm",13,9,0,0},
{"even",13,9,0,0},
{"evolute",13,9,0,0},
{"exact",13,9,0,0},
{"exbisector",13,9,0,0},
{"excircle",13,9,0,0},
{"execute",13,9,0,0},
{"exp",13,9,0,0},
{"exp2list",13,9,0,0| 1},
{"exp2pow",13,9,0,0},
{"exp2trig",13,9,0,0},
{"expexpand",13,9,0,0},
{"expln2trig",13,9,0,0},
{"exponential",13,9,0,0},
{"exponential_cdf",13,9,0,0},
{"exponential_icdf",13,9,0,0},
{"exponential_regression",13,9,0,0},
{"exponential_regression_plot",13,9,0,0},
{"exponentiald",13,9,0,0},
{"exponentiald_cdf",13,9,0,0},
{"exponentiald_icdf",13,9,0,0},
{"expr",13,9,0,0},
{"extend",13,9,0,0},
{"extract_measure",13,9,0,0},
{"ezgcd",13,9,0,0},
{"f2nd",13,9,0,0},
{"fMax",13,9,0,0},
{"fMin",13,9,0,0},
{"fPart",13,9,0,0},
{"faces",13,9,0,0},
{"facteurs_premiers",13,9,0,0},
{"factor",13,9,0,0},
{"factor_xn",13,9,0,0},
{"factorial",13,9,0,0},
{"factoriser",13,9,0,0},
{"factoriser_entier",13,9,0,0},
{"factoriser_sur_C",13,9,0,0},
{"factoriser_xn",13,9,0,0},
{"factors",13,9,0,0},
{"faire",13,59,0,0| 1},
{"fclose",13,9,0,0| 1},
{"fcoeff",13,9,0,0},
{"fft",13,9,0,0},
{"fft_mult_size",13,9,0,0},
{"fieldplot",13,9,0,0},
{"fill_rect",13,9,0,0},
{"filled",13,2,0,0},
{"filter",13,9,0,0},
{"fin_enregistrement",13,126,0,0},
{"find",13,9,0,0},
{"findhelp",13,9,0,0| 1},
{"fisher",13,9,0,0},
{"fisher_cdf",13,9,0,0},
{"fisher_icdf",13,9,0,0},
{"fisherd",13,9,0,0},
{"fisherd_cdf",13,9,0,0},
{"fisherd_icdf",13,9,0,0},
{"flatten",13,9,0,0},
{"flatten1",13,9,0,0},
{"float",13,9,0,0},
{"float2rational",13,9,0,0},
{"floor",13,9,0,0},
{"fmod",13,9,0,0},
{"fonction",13,73,0,0| 1},
{"fonction_derivee",13,9,0,0},
{"fopen",13,9,0,0},
{"format",13,9,0,0},
{"forward",13,9,0,0},
{"fourier_an",13,9,0,0},
{"fourier_bn",13,9,0,0},
{"fourier_cn",13,9,0,0},
{"fprint",13,9,0,0},
{"frac",13,9,0,0},
{"fracmod",13,9,0,0},
{"frame_2d",13,9,0,0},
{"frame_3d",13,9,0,0},
{"frenet",13,9,0,0},
{"frequencies",13,9,0,0},
{"frexp",13,9,0,0},
{"frobenius_norm",13,9,0,0},
{"froot",13,9,0,0},
{"fsolve",13,9,0,0| 1},
{"funcplot",13,9,0,0| 1},
{"function_diff",13,9,0,0},
{"fxnd",13,9,0,0},
{"galoisconj",13,9,0,0},
{"gammad",13,9,0,0},
{"gammad_cdf",13,9,0,0},
{"gammad_icdf",13,9,0,0},
{"gauche",13,9,0,0},
{"gauss",13,9,0,0},
{"gauss_seidel_linsolve",13,9,0,0},
{"gaussjord",13,9,0,0},
{"gaussquad",13,9,0,0},
{"gbasis",13,9,0,0},
{"gcd",13,9,0,0},
{"gcdex",13,9,0,0},
{"genpoly",13,9,0,0},
{"geo2d",13,9,0,0},
{"geo3d",13,9,0,0},
{"geometric",13,9,0,0},
{"geometric_cdf",13,9,0,0},
{"geometric_icdf",13,9,0,0},
{"getDenom",13,9,0,0},
{"getKey",13,9,0,0},
{"getNum",13,9,0,0},
{"getType",13,9,0,0},
{"get_key",13,9,0,0},
{"get_pixel",13,9,0,0},
{"ggb_ang",13,9,0,0},
{"ggbalt",13,9,0,0},
{"ggbsort",13,9,0,0},
{"giac",13,9,0,0},
{"goto",13,77,0,0},
{"grad",13,9,0,0| 1},
{"gramschmidt",13,9,0,0},
{"graph2tex",13,9,0,0},
{"graph3d2tex",13,9,0,0},
{"graph_scc",13,9,0,0},
{"graphe",13,9,0,0| 1},
{"graphe3d",13,9,0,0},
{"graphe_suite",13,9,0,0},
{"greduce",13,9,0,0},
{"green",13,2,0,0},
{"grid_paper",13,9,0,0},
{"groupermu",13,9,0,0},
{"hadamard",13,9,0,0},
{"half_cone",13,9,0,0},
{"half_line",13,9,0,0},
{"halftan",13,9,0,0},
{"halftan_hyp2exp",13,9,0,0},
{"halt",13,9,0,0| 1},
{"hamdist",13,9,0,0},
{"harmonic",13,9,0,0},
{"harmonic_conjugate",13,9,0,0},
{"harmonic_division",13,9,0,0| 1},
{"has",13,9,0,0},
{"hasard",13,77,0,0},
{"head",13,9,0,0},
{"heading",13,9,0,0},
{"heap_mult",13,9,0,0},
{"heapify",13,9,0,0},
{"heappop",13,9,0,0},
{"heappush",13,9,0,0},
{"help",13,9,0,0},
{"hermite",13,9,0,0},
{"hessenberg",13,9,0,0},
{"hessian",13,9,0,0| 1},
{"heugcd",13,9,0,0},
{"hexagon",13,9,0,0| 1},
{"hexprint",13,9,0,0},
{"hidden_name",13,2,0,0},
{"hideturtle",13,9,0,0},
{"hilbert",13,9,0,0},
{"histogram",13,9,0,0},
{"hold",13,9,0,0| 1},
{"homothety",13,9,0,0},
{"horner",13,9,0,0},
{"hp38",13,9,0,0},
{"hyp2exp",13,9,0,0},
{"hyperbola",13,9,0,0},
{"hyperplan",13,9,0,0},
{"hypersphere",13,9,0,0},
{"hypersurface",13,9,0,0},
{"iPart",13,9,0,0},
{"iabcuv",13,9,0,0},
{"ibasis",13,9,0,0},
{"ibpdv",13,9,0,0},
{"ibpu",13,9,0,0},
{"icdf",13,9,0,0},
{"ichinrem",13,9,0,0},
{"ichrem",13,9,0,0},
{"icontent",13,9,0,0},
{"icosahedron",13,9,0,0},
{"id",13,9,0,0},
{"identity",13,9,0,0},
{"idivis",13,9,0,0},
{"idn",13,9,0,0},
{"iegcd",13,9,0,0},
{"ifactor",13,9,0,0},
{"ifactors",13,9,0,0},
{"ifft",13,9,0,0},
{"igamma_exp",13,9,0,0},
{"igcd",13,9,0,0},
{"igcdex",13,9,0,0},
{"ihermite",13,9,0,0},
{"ilaplace",13,9,0,0},
{"im",13,9,0,0},
{"imag",13,9,0,0},
{"image",13,9,0,0},
{"implicit_diff",13,9,0,0},
{"implicitplot",13,9,0,0},
{"implicitplot3d",13,9,0,0},
{"inString",13,9,0,0},
{"in_ideal",13,9,0,0},
{"incircle",13,9,0,0},
{"increment",13,9,0,0| 1},
{"indets",13,9,0,0},
{"index",13,9,0,0},
{"inequationplot",13,9,0,0| 1},
{"inferieur_strict_sort",13,9,0,0},
{"innertln",13,9,0,0},
{"input",13,9,0,0| 1},
{"inputform",13,9,0,0| 1},
{"insert",13,9,0,0},
{"insmod",13,9,0,0},
{"int",13,9,0,0},
{"intDiv",13,9,0,0},
{"integer_format",13,9,0,0},
{"integrate",13,9,0,0| 1},
{"integrer",13,9,0,0},
{"inter",13,9,0,0},
{"interactive",13,9,0,0| 1},
{"interactive_odeplot",13,9,0,0},
{"interactive_plotode",13,9,0,0},
{"interp",13,9,0,0},
{"interval2center",13,9,0,0},
{"inv",13,9,0,0},
{"invd_blocksize",13,9,0,0},
{"inverse",13,9,0,0},
{"inversion",13,9,0,0},
{"invlaplace",13,9,0,0},
{"invztrans",13,9,0,0},
{"iquo",13,9,0,0},
{"iquorem",13,9,0,0},
{"iquosto",13,9,0,0},
{"iratrecon",13,9,0,0},
{"irem",13,9,0,0},
{"iremsto",13,9,0,0},
{"isPrime",13,9,0,0},
{"is_3dpoint",13,9,0,0},
{"is_collinear",13,9,0,0},
{"is_concyclic",13,9,0,0},
{"is_conjugate",13,9,0,0},
{"is_coplanar",13,9,0,0},
{"is_cospherical",13,9,0,0},
{"is_cycle",13,9,0,0},
{"is_element",13,9,0,0},
{"is_equilateral",13,9,0,0},
{"is_harmonic",13,9,0,0},
{"is_harmonic_circle_bundle",13,9,0,0},
{"is_harmonic_line_bundle",13,9,0,0},
{"is_included",13,9,0,0},
{"is_isosceles",13,9,0,0},
{"is_orthogonal",13,9,0,0},
{"is_parallel",13,9,0,0},
{"is_parallelogram",13,9,0,0},
{"is_permu",13,9,0,0},
{"is_perpendicular",13,9,0,0},
{"is_polynomial",13,9,0,0},
{"is_prime",13,9,0,0},
{"is_pseudoprime",13,9,0,0},
{"is_rectangle",13,9,0,0},
{"is_rhombus",13,9,0,0},
{"is_square",13,9,0,0},
{"isfinite",13,9,0,0},
{"isinf",13,9,0,0},
{"ismith",13,9,0,0},
{"isnan",13,9,0,0},
{"isobarycenter",13,9,0,0},
{"isom",13,9,0,0},
{"isopolygon",13,9,0,0},
{"isosceles_triangle",13,9,0,0},
{"isprime",13,9,0,0},
{"ithprime",13,9,0,0},
{"jacobi_linsolve",13,9,0,0},
{"jacobi_symbol",13,9,0,0},
{"javascript",13,9,0,0},
{"join",13,9,0,0},
{"jordan",13,9,0,0},
{"jump",13,126,0,0},
{"ker",13,9,0,0},
{"kernel",13,9,0,0},
{"keydown",13,9,0,0},
{"kill",13,9,0,0},
{"kolmogorovd",13,9,0,0},
{"kolmogorovt",13,9,0,0},
{"l1norm",13,9,0,0},
{"l2norm",13,9,0,0},
{"label",13,77,0,0},
{"lagrange",13,9,0,0},
{"laguerre",13,9,0,0},
{"lapack_limit",13,9,0,0},
{"laplace",13,9,0,0},
{"laplacian",13,9,0,0| 1},
{"latex",13,9,0,0},
{"lcm",13,9,0,0},
{"lcoeff",13,9,0,0},
{"ldegree",13,9,0,0},
{"ldexp",13,9,0,0},
{"left",13,9,0,0},
{"legend",13,9,0,0| 1},
{"legendre",13,9,0,0},
{"legendre_symbol",13,9,0,0},
{"len",13,9,0,0},
{"length",13,9,0,0},
{"leve_crayon",13,126,0,0},
{"lgcd",13,9,0,0},
{"lhs",13,9,0,0},
{"ligne_polygonale",13,9,0,0},
{"ligne_polygonale_pointee",13,9,0,0},
{"limit",13,9,0,0| 1},
{"limite",13,9,0,0},
{"lin",13,9,0,0},
{"line",13,9,0,0| 1},
{"line_inter",13,9,0,0},
{"line_paper",13,9,0,0},
{"line_segments",13,9,0,0},
{"linear_interpolate",13,9,0,0},
{"linear_regression",13,9,0,0},
{"linear_regression_plot",13,9,0,0},
{"lineariser",13,9,0,0},
{"lineariser_trigo",13,9,0,0},
{"linetan",13,9,0,0},
{"linfnorm",13,9,0,0},
{"link2giac",13,9,0,0},
{"linsolve",13,9,0,0| 1},
{"linspace",13,9,0,0},
{"lis",13,77,0,0| 1},
{"lis_phrase",13,77,0,0| 1},
{"list2exp",13,9,0,0},
{"list2mat",13,9,0,0},
{"listplot",13,9,0,0},
{"lll",13,9,0,0},
{"lll_reduce",13,9,0,0},
{"ln",13,9,0,0},
{"lnGamma_minus",13,9,0,0},
{"lname",13,9,0,0},
{"lncollect",13,9,0,0},
{"lnexpand",13,9,0,0},
{"locate",13,9,0,0},
{"locus",13,9,0,0| 1},
{"log10",13,9,0,0},
{"logarithmic_regression",13,9,0,0},
{"logarithmic_regression_plot",13,9,0,0},
{"logb",13,9,0,0},
{"logistic_regression",13,9,0,0},
{"logistic_regression_plot",13,9,0,0},
{"lower",13,9,0,0},
{"ls",13,9,0,0},
{"lsmod",13,9,0,0},
{"lsq",13,9,0,0},
{"lu",13,9,0,0},
{"lvar",13,9,0,0},
{"mRow",13,9,0,0},
{"mRowAdd",13,9,0,0},
{"magenta",13,2,0,0},
{"makelist",13,9,0,0},
{"makemat",13,9,0,0},
{"makemod",13,9,0,0},
{"makesuite",13,9,0,0},
{"makevector",13,9,0,0},
{"mantissa",13,9,0,0},
{"map",13,9,0,0},
{"maple2mupad",13,9,0,0| 1},
{"maple2xcas",13,9,0,0| 1},
{"maple_ifactors",13,9,0,0},
{"maple_mode",13,9,0,0},
{"markov",13,9,0,0},
{"mat2list",13,9,0,0},
{"mathml",13,9,0,0},
{"matpow",13,9,0,0},
{"matrix",13,9,0,0},
{"matrix_norm",13,9,0,0},
{"max",13,9,0,0},
{"max_algext",13,9,0,0},
{"maxnorm",13,9,0,0},
{"mean",13,9,0,0},
{"median",13,9,0,0},
{"median_line",13,9,0,0},
{"member",13,9,0,0| 1},
{"mgf",13,9,0,0},
{"mid",13,9,0,0},
{"midpoint",13,9,0,0},
{"min",13,9,0,0},
{"min_proba_time",13,9,0,0},
{"mkdir",13,9,0,0},
{"mkisom",13,9,0,0},
{"mksa",13,9,0,0},
{"modgcd",13,9,0,0},
{"modgcd_cachesize",13,9,0,0},
{"modp",13,9,0,0},
{"mods",13,9,0,0},
{"monotonic",13,9,0,0},
{"montre_tortue",13,126,0,0},
{"more",13,9,0,0},
{"moustache",13,9,0,0},
{"moyal",13,9,0,0},
{"moyenne",13,9,0,0},
{"mpzclass_allowed",13,9,0,0},
{"mul",13,9,0,0},
{"mult_c_conjugate",13,9,0,0| 1},
{"mult_conjugate",13,9,0,0},
{"multcrement",13,9,0,0| 1},
{"multinomial",13,9,0,0},
{"multiplier_conjugue",13,9,0,0},
{"multiplier_conjugue_complexe",13,9,0,0},
{"multiply",13,9,0,0},
{"mupad2maple",13,9,0,0| 1},
{"mupad2xcas",13,9,0,0| 1},
{"nCr",13,9,0,0},
{"nDeriv",13,9,0,0},
{"nInt",13,9,0,0},
{"nPr",13,9,0,0},
{"nSolve",13,9,0,0},
{"ncols",13,9,0,0},
{"negbinomial",13,9,0,0},
{"negbinomial_cdf",13,9,0,0},
{"negbinomial_icdf",13,9,0,0},
{"newList",13,9,0,0},
{"newMat",13,9,0,0},
{"newton",13,9,0,0},
{"nextperm",13,9,0,0},
{"nextprime",13,9,0,0},
{"nodisp",13,9,0,0},
{"non",13,11,0,0},
{"non_recursive_normal",13,9,0,0},
{"nop",13,9,0,0},
{"nops",13,9,0,0},
{"norm",13,9,0,0},
{"normal",13,9,0,0},
{"normal_cdf",13,9,0,0},
{"normal_icdf",13,9,0,0},
{"normald",13,9,0,0},
{"normald_cdf",13,9,0,0},
{"normald_icdf",13,9,0,0},
{"normalize",13,9,0,0},
{"normalt",13,9,0,0},
{"nprimes",13,9,0,0},
{"nrows",13,9,0,0},
{"nuage_points",13,9,0,0},
{"nullspace",13,9,0,0},
{"numer",13,9,0,0},
{"octahedron",13,9,0,0},
{"octprint",13,9,0,0},
{"odd",13,9,0,0},
{"odeplot",13,9,0,0},
{"odesolve",13,9,0,0},
{"op",13,9,0,0},
{"open",13,9,0,0},
{"open_polygon",13,9,0,0},
{"or",13,33,0,0| 1},
{"ord",13,9,0,0},
{"order_size",13,9,0,0},
{"ordinate",13,9,0,0},
{"ordonnee",13,9,0,0},
{"orthocenter",13,9,0,0},
{"orthogonal",13,9,0,0},
{"os_version",13,9,0,0},
{"osculating_circle",13,9,0,0},
{"ou",13,33,0,0| 1},
{"output",13,9,0,0| 1},
{"p1oc2",13,9,0,0},
{"p1op2",13,9,0,0},
{"pa2b2",13,9,0,0},
{"pade",13,9,0,0},
{"padic_linsolve",13,9,0,0},
{"parabola",13,9,0,0},
{"parabolic_interpolate",13,9,0,0},
{"parallel",13,9,0,0},
{"parallelepiped",13,9,0,0},
{"parallelogram",13,9,0,0| 1},
{"parameq",13,9,0,0},
{"parameter",13,9,0,0},
{"paramplot",13,9,0,0| 1},
{"pari",13,9,0,0| 1},
{"pari_unlock",13,9,0,0| 1},
{"part",13,9,0,0},
{"partfrac",13,9,0,0},
{"pas",13,60,0,0| 1},
{"pas_de_cote",13,126,0,0},
{"pcar",13,9,0,0},
{"pcar_hessenberg",13,9,0,0},
{"pcoeff",13,9,0,0},
{"pd",13,126,0,0},
{"pencolor",13,126,0,0},
{"pendown",13,126,0,0},
{"pente",13,9,0,0},
{"penup",13,126,0,0},
{"perimeter",13,9,0,0},
{"perimeterat",13,9,0,0| 1},
{"perimeteratraw",13,9,0,0},
{"perm",13,9,0,0},
{"perminv",13,9,0,0},
{"permu2cycles",13,9,0,0},
{"permu2mat",13,9,0,0},
{"permuorder",13,9,0,0},
{"perpen_bisector",13,9,0,0},
{"perpendicular",13,9,0,0},
{"peval",13,9,0,0},
{"piecewise",13,9,0,0| 1},
{"pivot",13,9,0,0},
{"pixoff",13,9,0,0},
{"pixon",13,9,0,0},
{"plane",13,9,0,0},
{"plot",13,9,0,0| 1},
{"plot3d",13,9,0,0},
{"plot_style",13,9,0,0},
{"plotarea",13,9,0,0},
{"plotcdf",13,9,0,0},
{"plotcontour",13,9,0,0| 1},
{"plotdensity",13,9,0,0| 1},
{"plotfield",13,9,0,0},
{"plotfunc",13,9,0,0| 1},
{"plotimplicit",13,9,0,0},
{"plotinequation",13,9,0,0| 1},
{"plotlist",13,9,0,0},
{"plotmatrix",13,9,0,0},
{"plotode",13,9,0,0},
{"plotparam",13,9,0,0| 1},
{"plotpolar",13,9,0,0| 1},
{"plotseq",13,9,0,0},
{"pmin",13,9,0,0},
{"pnt",13,9,0,0},
{"point",13,9,0,0},
{"point2d",13,9,0,0| 1},
{"point3d",13,9,0,0| 1},
{"pointer",13,9,0,0},
{"poisson",13,9,0,0},
{"poisson_cdf",13,9,0,0},
{"poisson_icdf",13,9,0,0},
{"polar",13,9,0,0},
{"polar2rectangular",13,9,0,0},
{"polar_coordinates",13,9,0,0},
{"polar_point",13,9,0,0},
{"polarplot",13,9,0,0| 1},
{"pole",13,9,0,0},
{"poly2symb",13,9,0,0},
{"polyEval",13,9,0,0},
{"polygamma",13,9,0,0},
{"polygon",13,9,0,0},
{"polygone_rempli",13,126,0,0},
{"polygonplot",13,9,0,0},
{"polygonscatterplot",13,9,0,0},
{"polyhedron",13,9,0,0},
{"polynomial_regression",13,9,0,0},
{"polynomial_regression_plot",13,9,0,0},
{"pop",13,9,0,0},
{"position",13,126,0,0},
{"poslbdLMQ",13,9,0,0},
{"posubLMQ",13,9,0,0},
{"potential",13,9,0,0| 1},
{"pour",13,56,0,0| 1},
{"pow2exp",13,9,0,0},
{"power_regression",13,9,0,0},
{"power_regression_plot",13,9,0,0},
{"powermod",13,9,0,0},
{"powerpc",13,9,0,0},
{"powexpand",13,9,0,0},
{"powmod",13,9,0,0},
{"prediction",13,9,0,0},
{"prediction95",13,9,0,0},
{"prepend",13,9,0,0},
{"preval",13,9,0,0},
{"prevperm",13,9,0,0},
{"prevprime",13,9,0,0},
{"primpart",13,9,0,0},
{"print",13,9,0,0| 1},
{"printf",13,9,0,0},
{"printpow",13,9,0,0},
{"prism",13,9,0,0},
{"product",13,9,0,0| 1},
{"prog_eval_level",13,9,0,0},
{"projection",13,9,0,0},
{"proot",13,9,0,0},
{"propFrac",13,9,0,0},
{"propfrac",13,9,0,0},
{"psrgcd",13,9,0,0},
{"ptayl",13,9,0,0},
{"pu",13,126,0,0},
{"pwd",13,9,0,0},
{"pyramid",13,9,0,0},
{"python",13,9,0,0},
{"python_compat",13,9,0,0},
{"python_list",13,9,0,0},
{"q2a",13,9,0,0},
{"qr",13,9,0,0},
{"quadric",13,9,0,0},
{"quadrilateral",13,9,0,0},
{"quantile",13,9,0,0},
{"quartile1",13,9,0,0},
{"quartile3",13,9,0,0},
{"quartiles",13,9,0,0},
{"quaternion",13,9,0,0},
{"quest",13,9,0,0},
{"quo",13,9,0,0},
{"quorem",13,9,0,0},
{"quote",13,9,0,0| 1},
{"r2e",13,9,0,0},
{"radical_axis",13,9,0,0},
{"radius",13,9,0,0},
{"ramene",13,126,0,0},
{"rand",13,9,0,0},
{"randMat",13,9,0,0},
{"randNorm",13,9,0,0},
{"randPoly",13,9,0,0},
{"randbinomial",13,9,0,0},
{"randchisquare",13,9,0,0},
{"randchisquared",13,9,0,0},
{"randexp",13,9,0,0},
{"randfisher",13,9,0,0},
{"randfisherd",13,9,0,0},
{"randgeometric",13,9,0,0},
{"randint",13,9,0,0},
{"randmarkov",13,9,0,0},
{"randmatrix",13,9,0,0},
{"randmultinomial",13,9,0,0},
{"randnormald",13,9,0,0},
{"random",13,9,0,0},
{"randperm",13,9,0,0},
{"randpoisson",13,9,0,0},
{"randpoly",13,9,0,0},
{"randrange",13,9,0,0},
{"randstudent",13,9,0,0},
{"randstudentd",13,9,0,0},
{"randvector",13,9,0,0},
{"range",13,9,0,0},
{"rank",13,9,0,0},
{"ranm",13,9,0,0},
{"ranv",13,9,0,0},
{"rassembler_trigo",13,9,0,0},
{"rat_jordan",13,9,0,0},
{"rat_jordan_block",13,9,0,0},
{"rationalroot",13,9,0,0},
{"ratnormal",13,9,0,0},
{"rayon",13,9,0,0},
{"rdiv",13,9,0,0},
{"re",13,9,0,0},
{"read",13,77,0,0},
{"read16",13,9,0,0},
{"read32",13,9,0,0},
{"read_nand",13,9,0,0},
{"readrgb",13,9,0,0},
{"readwav",13,9,0,0},
{"real",13,9,0,0},
{"realproot",13,9,0,0},
{"realroot",13,9,0,0},
{"reciprocation",13,9,0,0},
{"rectangle",13,9,0,0| 1},
{"rectangle_plein",13,126,0,0},
{"rectangular2polar",13,9,0,0},
{"rectangular2spherical",13,9,0,0},
{"rectangular_coordinates",13,9,0,0},
{"recule",13,126,0,0},
{"red",13,2,0,0},
{"redim",13,9,0,0},
{"reduced_conic",13,9,0,0},
{"reduced_quadric",13,9,0,0},
{"ref",13,9,0,0},
{"reflection",13,9,0,0},
{"regroup",13,9,0,0},
{"rem",13,9,0,0},
{"remain",13,9,0,0},
{"remove",13,9,0,0},
{"remove_language",13,9,0,0},
{"reorder",13,9,0,0},
{"repete",13,77,0,0| 1},
{"replace",13,9,0,0},
{"reset",13,126,0,0},
{"reset_solve_counter",13,9,0,0},
{"residue",13,9,0,0},
{"resoudre",13,9,0,0| 1},
{"resoudre_dans_C",13,9,0,0| 1},
{"resoudre_systeme_lineaire",13,9,0,0| 1},
{"restart",13,77,0,0},
{"restart_modes",13,77,0,0},
{"restart_vars",13,77,0,0},
{"resultant",13,9,0,0},
{"reverse",13,9,0,0},
{"reverse_rsolve",13,9,0,0},
{"reverse",13,9,0,0},
{"revert",13,9,0,0},
{"revlist",13,9,0,0},
{"rgb",13,9,0,0},
{"rhombus",13,9,0,0| 1},
{"rhs",13,9,0,0},
{"right",13,9,0,0},
{"right_triangle",13,9,0,0| 1},
{"rm",13,9,0,0},
{"rm_a_z",13,9,0,0},
{"rm_all_vars",13,9,0,0},
{"rmbreakpoint",13,9,0,0| 1},
{"rmmod",13,9,0,0},
{"rmwatch",13,9,0,0| 1},
{"romberg",13,9,0,0},
{"rond",13,126,0,0},
{"rootof",13,9,0,0},
{"roots",13,9,0,0},
{"rotate",13,9,0,0},
{"rotation",13,9,0,0},
{"round",13,9,0,0},
{"row",13,9,0,0},
{"rowAdd",13,9,0,0},
{"rowDim",13,9,0,0},
{"rowNorm",13,9,0,0},
{"rowSwap",13,9,0,0},
{"rowdim",13,9,0,0},
{"rownorm",13,9,0,0},
{"rowspace",13,9,0,0},
{"rowswap",13,9,0,0},
{"rpn",13,9,0,0},
{"rref",13,9,0,0},
{"rsolve",13,9,0,0| 1},
{"saisir",13,9,0,0| 1},
{"saute",13,126,0,0},
{"sauve",13,126,0,0| 1},
{"save_history",13,9,0,0},
{"scalarProduct",13,9,0,0},
{"scalar_product",13,9,0,0},
{"scale",13,9,0,0},
{"scaleadd",13,9,0,0},
{"scatterplot",13,9,0,0},
{"schur",13,9,0,0},
{"sec",13,9,0,0},
{"sech",13,9,0,0},
{"segment",13,9,0,0},
{"select",13,9,0,0},
{"semi_augment",13,9,0,0},
{"seq",13,9,0,0| 1},
{"seqplot",13,9,0,0},
{"seqsolve",13,9,0,0| 1},
{"series",13,9,0,0},
{"set_language",13,9,0,0},
{"set_pixel",13,9,0,0},
{"shift",13,9,0,0},
{"shift_phase",13,9,0,0},
{"show",13,9,0,0},
{"show_language",13,9,0,0},
{"showturtle",13,9,0,0},
{"shuffle",13,9,0,0},
{"si",13,46,0,0| 1},
{"sialorssinon",13,51,0,0| 1},
{"sign",13,9,0,0},
{"signature",13,9,0,0},
{"signe",13,126,0,0},
{"similarity",13,9,0,0},
{"simp2",13,9,0,0},
{"simplex_reduce",13,9,0,0},
{"simplifier",13,9,0,0},
{"simplify",13,9,0,0},
{"simult",13,9,0,0},
{"sin",13,9,0,0},
{"sin2costan",13,9,0,0},
{"sin_regression",13,9,0,0},
{"sin_regression_plot",13,9,0,0},
{"sincos",13,9,0,0},
{"single_inter",13,9,0,0},
{"singular",13,9,0,0},
{"sinh",13,9,0,0},
{"sinon",13,50,0,0| 1},
{"size",13,9,0,0},
{"sizes",13,9,0,0},
{"skip",13,126,0,0},
{"sleep",13,9,0,0},
{"slope",13,9,0,0},
{"slopeat",13,9,0,0| 1},
{"slopeatraw",13,9,0,0},
{"smith",13,9,0,0},
{"smod",13,9,0,0},
{"snedecor",13,9,0,0},
{"snedecor_cdf",13,9,0,0},
{"snedecor_icdf",13,9,0,0},
{"snedecord",13,9,0,0},
{"snedecord_cdf",13,9,0,0},
{"snedecord_icdf",13,9,0,0},
{"solve",13,9,0,0| 1},
{"solve_zero_extremum",13,9,0,0| 1},
{"somme",13,9,0,0| 1},
{"sommet",13,9,0,0},
{"sort",13,9,0,0},
{"sorta",13,9,0,0},
{"sortd",13,9,0,0},
{"sorted",13,9,0,0},
{"soundsec",13,9,0,0},
{"speed",13,126,0,0},
{"sphere",13,9,0,0},
{"spherical2rectangular",13,9,0,0},
{"spline",13,9,0,0},
{"split",13,9,0,0},
{"spread2mathml",13,9,0,0},
{"spreadsheet",13,9,0,0},
{"sq",13,9,0,0},
{"sqrfree",13,9,0,0},
{"sqrt",13,9,0,0},
{"square",13,9,0,0| 1},
{"srand",13,77,0,0},
{"sst",13,9,0,0| 1},
{"sst_in",13,9,0,0| 1},
{"stdDev",13,9,0,0},
{"stddev",13,9,0,0},
{"stddevp",13,9,0,0},
{"step_infolevel",13,9,0,0},
{"sto",13,9,0,0},
{"str",13,9,0,0},
{"strassen_limit",13,9,0,0},
{"string",13,9,0,0},
{"strip",13,9,0,0},
{"student",13,9,0,0},
{"student_cdf",13,9,0,0},
{"student_icdf",13,9,0,0},
{"studentd",13,9,0,0},
{"studentd_cdf",13,9,0,0},
{"studentd_icdf",13,9,0,0},
{"studentt",13,9,0,0},
{"sturm",13,9,0,0},
{"sturmab",13,9,0,0},
{"sturmseq",13,9,0,0},
{"subMat",13,9,0,0},
{"submatrix",13,9,0,0},
{"subst",13,9,0,0},
{"substituer",13,9,0,0},
{"subtype",13,9,0,0},
{"sum",13,9,0,0| 1},
{"sum_riemann",13,9,0,0},
{"suppress",13,9,0,0},
{"surd",13,9,0,0},
{"svd",13,9,0,0},
{"svl",13,9,0,0},
{"swapcol",13,9,0,0},
{"swaprow",13,9,0,0},
{"switch_axes",13,9,0,0},
{"sylvester",13,9,0,0},
{"symb2poly",13,9,0,0},
{"syst2mat",13,9,0,0},
{"tCollect",13,9,0,0},
{"tExpand",13,9,0,0},
{"table",13,9,0,0},
{"tablefunc",13,9,0,0},
{"tableseq",13,9,0,0| 1},
{"tabvar",13,9,0,0},
{"tail",13,9,0,0},
{"tan",13,9,0,0},
{"tan2cossin2",13,9,0,0},
{"tan2sincos",13,9,0,0},
{"tan2sincos2",13,9,0,0},
{"tangent",13,9,0,0},
{"tangente",13,9,0,0},
{"tanh",13,9,0,0},
{"tantque",13,62,0,0| 1},
{"taux_accroissement",13,9,0,0},
{"taylor",13,9,0,0},
{"tchebyshev1",13,9,0,0},
{"tchebyshev2",13,9,0,0},
{"tcoeff",13,9,0,0},
{"tcollect",13,9,0,0},
{"tcollectsin",13,9,0,0},
{"testfunc",13,9,0,0},
{"tests",13,9,0,0},
{"tetrahedron",13,9,0,0},
{"texpand",13,9,0,0},
{"textinput",13,9,0,0| 1},
{"threads_allowed",13,9,0,0},
{"throw",13,77,0,0},
{"time",13,9,0,0| 1},
{"tlin",13,9,0,0},
{"total_degree",13,9,0,0},
{"tourne_droite",13,126,0,0},
{"tourne_gauche",13,126,0,0},
{"trace",13,9,0,0},
{"tran",13,9,0,0},
{"translation",13,9,0,0},
{"transpose",13,9,0,0},
{"triangle",13,9,0,0},
{"triangle_paper",13,9,0,0},
{"triangle_plein",13,126,0,0},
{"trig2exp",13,9,0,0},
{"trigcos",13,9,0,0},
{"trigexpand",13,9,0,0},
{"trigsin",13,9,0,0},
{"trigtan",13,9,0,0},
{"trn",13,9,0,0},
{"trunc",13,9,0,0},
{"truncate",13,9,0,0},
{"tsimplify",13,9,0,0},
{"turtle_stack",13,126,0,0},
{"type",13,9,0,0},
{"ufactor",13,9,0,0},
{"unapply",13,9,0,0| 1},
{"unarchive",13,9,0,0},
{"unarchive_ti",13,9,0,0},
{"uniform",13,9,0,0},
{"uniform_cdf",13,9,0,0},
{"uniform_icdf",13,9,0,0},
{"uniformd",13,9,0,0},
{"uniformd_cdf",13,9,0,0},
{"uniformd_icdf",13,9,0,0},
{"unitV",13,9,0,0},
{"unquote",13,9,0,0},
{"up",13,126,0,0},
{"upper",13,9,0,0},
{"usimplify",13,9,0,0},
{"valuation",13,9,0,0},
{"vandermonde",13,9,0,0},
{"variance",13,9,0,0},
{"vector",13,9,0,0},
{"vers",13,126,0,0},
{"version",13,9,0,0},
{"vertices",13,9,0,0},
{"vertices_abc",13,9,0,0},
{"vertices_abca",13,9,0,0},
{"vitesse_tortue",13,126,0,0},
{"vpotential",13,9,0,0| 1},
{"warn_equal_in_prog",13,9,0,0},
{"watch",13,9,0,0| 1},
{"weibull",13,9,0,0},
{"weibull_cdf",13,9,0,0},
{"weibull_icdf",13,9,0,0},
{"weibulld",13,9,0,0},
{"weibulld_cdf",13,9,0,0},
{"weibulld_icdf",13,9,0,0},
{"whattype",13,9,0,0},
{"when",13,9,0,0| 1},
{"white",13,2,0,0},
{"widget_size",13,9,0,0},
{"wilcoxonp",13,9,0,0},
{"wilcoxons",13,9,0,0},
{"wilcoxont",13,9,0,0},
{"with_sqrt",13,9,0,0},
{"write",13,9,0,0| 1},
{"write16",13,9,0,0},
{"write32",13,9,0,0},
{"writergb",13,9,0,0},
{"writewav",13,9,0,0},
{"wz_certificate",13,9,0,0},
{"xcas",13,9,0,0},
{"xcas_mode",13,9,0,0},
{"xyztrange",13,9,0,0},
{"yellow",13,2,0,0},
{"zeros",13,9,0,0| 1},
{"zip",13,9,0,0},
{"ztrans",13,9,0,0},
{"ΔLIST",13,-124,0,0},
{"ΠLIST",13,-124,0,0},
{"ΣLIST",13,-124,0,0},
{"∂",13,-124,0,0| 1},
{"Σ",13,-124,0,0| 1},
{"∫",13,-124,0,0| 1}
